@@ -89,7 +89,7 @@ int lttng_uprobes_event_handler_pre(struct uprobe_consumer *uc, struct pt_regs *
 			container_of(event, struct lttng_kernel_event_notifier, parent);
 		struct lttng_kernel_notification_ctx notif_ctx;
 
-		notif_ctx.eval_capture = LTTNG_READ_ONCE(event_notifier->eval_capture);
+		notif_ctx.eval_capture = false;
 		event_notifier->notification_send(event_notifier, NULL, NULL, &notif_ctx);
 		break;
 	}
